# ptextpad
[![pytest](https://github.com/ffreemt/ptextpad/actions/workflows/routine-tests.yml/badge.svg)](https://github.com/ffreemt/ptextpad/actions)[![python](https://img.shields.io/static/v1?label=python+&message=3.8.3%2B&color=blue)](https://www.python.org/downloads/)[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)[![PyPI version](https://badge.fury.io/py/ptextpad.svg)](https://badge.fury.io/py/ptextpad)

a parallel text editor

## Install it

```shell
pip install ptextpad --upgrade
# pip install git+https://github.com/ffreemt/ptextpad
# poetry add git+https://github.com/ffreemt/ptextpad
# git clone https://github.com/ffreemt/ptextpad && cd ptextpad
```

## Use it
```shell
python -m ptextpad
# or
# ptextpad
```

Set `LOGLEVEL=10` to see loads of debug messages, e.g.
```shell
set LOGLEVEL=10  
# linux/mac: export LOGLEVEL=10
python -m ptextpad
```
